@@ -1,11 +1,14 @@
 # Copyright (C) 2009, Thomas Leonard
 # See the README file for details, or visit http://0install.net.
 
-from zeroinstall import _, gobject
+from zeroinstall import _
 from zeroinstall.support import tasks
 from zeroinstall.injector import handler, download
 
-version = '2.0'
+gobject = tasks.get_loop().gobject
+glib = tasks.get_loop().glib
+
+version = '2.3.2'
 
 class GUIHandler(handler.Handler):
 	dl_callbacks = None		# Download -> [ callback ]
@@ -28,14 +31,14 @@ class GUIHandler(handler.Handler):
 				self.mainwindow.update_download_status(only_update_visible = True)
 				return True
 			pulse()
-			self.pulse = gobject.timeout_add(200, pulse)
+			self.pulse = glib.timeout_add(200, pulse)
 		elif len(self.monitored_downloads) == 0:
 			# Delay before resetting, in case we start a new download quickly
-			gobject.timeout_add(500, self._reset_counters)
+			glib.timeout_add(500, self._reset_counters)
 
 			# Stop animation
 			if self.pulse:
-				gobject.source_remove(self.pulse)
+				glib.source_remove(self.pulse)
 				self.pulse = None
 				self.mainwindow.update_download_status()
 
