@@ -13,17 +13,9 @@ The Python implementation of the Zero Install injector is divided into five sub-
 @var _: a function for translating strings using the zero-install domain (for use internally by Zero Install)
 """
 
-version = '2.0'
+version = '2.3.2'
 
-import sys, logging
-if sys.version_info[0] > 2:
-	try:
-		from gi.repository import GObject as gobject
-	except ImportError:
-		import gobject
-else:
-	import gobject
-gobject.threads_init()
+import logging
 
 logger = logging.getLogger('0install')
 
@@ -54,6 +46,7 @@ class NeedDownload(SafeException):
 	"""Thrown if we tried to start a download and downloading is
 	disabled."""
 	def __init__(self, url):
+		"""@type url: str"""
 		Exception.__init__(self, _("Would download '%s'") % url)
 
 class DryRun(SafeException):
